==> deepset_cloud_sdk-0.0.1.tar.gz: deepset_cloud_sdk-0.0.1/README.md <==
<p align="center">
  <a href="https://cloud.deepset.ai/"><img src="/assets/logo.png"  alt="deepset Cloud SDK"></a>
</p>

[![Tests](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/continuous-integration.yml/badge.svg)](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/continuous-integration.yml)
[![Deploy PyPi](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/deploy-prod.yml/badge.svg)](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/deploy-prod.yml)
[![Compliance Checks](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/compliance.yml/badge.svg)](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/compliance.yml)

The deepset Cloud SDK is an open source software development kit that provides convenient access and integration with deepset Cloud, a powerful cloud offering for various natural language processing (NLP) tasks.
This README provides an overview of the SDK and its features, and information on contributing to the project and exploring related resources.

# Supported Features
The current version of the SDK focuses on providing an easy way to upload files to deepset Cloud for further processing and analysis. For detailed instructions and examples, see file_uploads/README.md.

## Examples
The following examples demonstrate how to use the deepset Cloud SDK to interact with deepset Cloud.
- [Upload datasets to deepset Cloud](/examples/upload.py)

## Installation
The deepset Cloud SDK is available on PyPI and can be installed using pip:
```bash
pip install deepset-cloud-sdk
```


## Contributing
We welcome contributions from the open source community to enhance the deepset Cloud SDK. I
f you would like to contribute, refer to the [CONTRIBUTING.md](CONTRIBUTING.md) file for guidelines and instructions on how to get started.
We appreciate your contributions, whether they're bug fixes, new features, or documentation improvements.


---

## Interested in deepset Cloud?
If you are interested in exploring deepset Cloud, visit cloud.deepset.ai.
deepset Cloud provides a range of NLP capabilities and services to help you build and deploy powerful
natural language processing applications.

## Interested in Haystack?
deepset Cloud is powered by Haystack, an open source framework for building end-to-end NLP pipelines.
 - [Project website](https://haystack.deepset.ai/)
 - [GitHub repository](https://github.com/deepset-ai/haystack)

==> deepset_cloud_sdk-0.0.3.tar.gz: deepset_cloud_sdk-0.0.3/README.md <==
<p align="center">
  <a href="https://cloud.deepset.ai/"><img src="/assets/logo.png"  alt="deepset Cloud SDK"></a>
</p>

[![Tests](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/continuous-integration.yml/badge.svg)](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/continuous-integration.yml)
[![Deploy PyPi](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/deploy-prod.yml/badge.svg)](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/deploy-prod.yml)
[![Compliance Checks](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/compliance.yml/badge.svg)](https://github.com/deepset-ai/deepset-cloud-sdk/actions/workflows/compliance.yml)

The deepset Cloud SDK is an open source software development kit that provides convenient access and integration with deepset Cloud, a powerful cloud offering for various natural language processing (NLP) tasks.
This README provides an overview of the SDK and its features, and information on contributing to the project and exploring related resources.

# Supported Features
The current version of the SDK focuses on providing an easy way to upload files to deepset Cloud for further processing and analysis. For detailed instructions and examples, see file_uploads/README.md.

## Examples
The following examples demonstrate how to use the deepset Cloud SDK to interact with deepset Cloud.
- [Upload datasets to deepset Cloud via SDK](/examples/sdk/upload.py)
- [Upload datasets to deepset Cloud via CLI](/examples/cli/README.md)

## CLI
You can use the deepset Cloud SDK in the command line as well. For more information, see the [CLI documentation](/examples/cli/README.md).

## Installation
The deepset Cloud SDK is available on PyPI and can be installed using pip:
```bash
pip install deepset-cloud-sdk
```


## Contributing
We welcome contributions from the open source community to enhance the deepset Cloud SDK. I
f you would like to contribute, refer to the [CONTRIBUTING.md](CONTRIBUTING.md) file for guidelines and instructions on how to get started.
We appreciate your contributions, whether they're bug fixes, new features, or documentation improvements.


---

## Interested in deepset Cloud?
If you are interested in exploring deepset Cloud, visit cloud.deepset.ai.
deepset Cloud provides a range of NLP capabilities and services to help you build and deploy powerful
natural language processing applications.

## Interested in Haystack?
deepset Cloud is powered by Haystack, an open source framework for building end-to-end NLP pipelines.
 - [Project website](https://haystack.deepset.ai/)
 - [GitHub repository](https://github.com/deepset-ai/haystack)
